@@ -2,11 +2,12 @@ use strict;
 use warnings;
 package Ouch;
 {
-  $Ouch::VERSION = '0.0406';
+  $Ouch::VERSION = '0.0407';
 }
 use Carp qw(longmess shortmess);
 use parent 'Exporter';
 use overload bool => sub {1}, q{""} => 'scalar', fallback => 1;
+use Scalar::Util qw(blessed);
 
 our @EXPORT = qw(bleep ouch kiss hug barf);
 our @EXPORT_OK = qw(try throw catch catch_all caught caught_all);
@@ -36,7 +37,7 @@ sub throw {  # alias
 sub kiss {
   my ($code, $e) = @_;
   $e ||= $@;
-  if (ref $e eq 'Ouch' && $e->code eq $code) {
+  if (blessed $e && $e->isa('Ouch') && $e->code eq $code) {
     return 1;
   }
   return 0;
@@ -67,7 +68,7 @@ sub caught_all {
 sub bleep {
   my ($e) = @_;
   $e ||= $@;
-  if (ref $e eq 'Ouch') {
+  if (blessed $e && $e->isa('Ouch')) {
     return $e->message;
   }
   else {
@@ -85,7 +86,7 @@ sub barf {
     my ($e) = @_;
     my $code;
     $e ||= $@;
-    if (ref $e eq 'Ouch') {
+    if (blessed $e && $e->isa('Ouch')) {
         $code = $e->code;
     } 
     else {
@@ -136,7 +137,7 @@ Ouch - Exceptions that don't hurt.
 
 =head1 VERSION
 
-version 0.0406
+version 0.0407
 
 =head1 SYNOPSIS
 
